@@ -1,16 +1,15 @@
 data("merzbach", package = "folio")
 
-## Coerce the merzbach dataset to a count matrix
 ## Keep only decoration types that have a maximum frequency of at least 50
 keep <- apply(X = merzbach, MARGIN = 2, FUN = function(x) max(x) >= 50)
-counts <- as_count(merzbach[, keep])
+counts <- merzbach[, keep]
 
 ## Group by phase
 ## We use the row names as time coordinates (roman numerals)
-set_dates(counts) <- as.numeric(utils::as.roman(rownames(counts)))
+dates <- as.numeric(utils::as.roman(rownames(counts)))
 
 ## Frequency Increment Test
-freq <- fit(counts)
+freq <- fit(counts, dates)
 
 ## Plot time vs abundance and highlight selection
 plot(freq)
